@@ -8,6 +8,7 @@ from typing import (
     Any,
     Callable,
     List,
+    NoReturn,
     Optional,
     Type as T,
     TypeVar,
@@ -126,7 +127,7 @@ class cached_property:
         ...
 
     @overload
-    def __get__(self, obj: I, cls: T[I]) -> O:
+    def __get__(self, obj: I, cls: T[I]) -> O:  # type: ignore
         ...
 
     def __get__(self, obj: Optional[I], cls: T[I]) -> Union["cached_property", O]:
@@ -292,7 +293,7 @@ def write_stderr(s: str) -> None:
     sys.stderr.write(s + "\n")
 
 
-def fatal(s: str = "", code: int = 1) -> None:
+def fatal(s: str = "", code: int = 1) -> NoReturn:
     """Exit the whole program with given code and message."""
     if s:
         write_stderr(s)
